Package: brglm
Type: Package
Title: Bias Reduction in Binomial-Response Generalized Linear Models
Version: 0.7.3
Authors@R: person(given = "Ioannis", family = "Kosmidis", role = c("aut", "cre"), email = "ioannis.kosmidis@warwick.ac.uk", comment = c(ORCID = "0000-0003-1556-0302"))
URL: https://github.com/ikosmidis/brglm
BugReports: https://github.com/ikosmidis/brglm/issues
Description: Fit generalized linear models with binomial responses using either an adjusted-score approach to bias reduction or maximum penalized likelihood where penalization is by Jeffreys invariant prior. These procedures return estimates with improved frequentist properties (bias, mean squared error) that are always finite even in cases where the maximum likelihood estimates are infinite (data separation). Fitting takes place by fitting generalized linear models on iteratively updated pseudo-data. The interface is essentially the same as 'glm'.  More flexibility is provided by the fact that custom pseudo-data representations can be specified and used for model fitting. Functions are provided for the construction of confidence intervals for the reduced-bias estimates.
License: GPL (>= 2)
Depends: R (>= 2.6.0), profileModel
Suggests: MASS
NeedsCompilation: yes
Packaged: 2025-09-16 10:23:40 UTC; yiannis
Author: Ioannis Kosmidis [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1556-0302>)
Maintainer: Ioannis Kosmidis <ioannis.kosmidis@warwick.ac.uk>
Repository: CRAN
Date/Publication: 2025-09-16 10:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 23:38:05 UTC; unix
Archs: brglm.so.dSYM
